==> commons-1.6.0-alpha2-sources.jar: com/flybits/internal/db/CommonsDatabase.java <==
package com.flybits.internal.db;

import android.arch.persistence.db.SupportSQLiteDatabase;
import android.arch.persistence.room.Database;
import android.arch.persistence.room.Room;
import android.arch.persistence.room.RoomDatabase;
import android.arch.persistence.room.migration.Migration;
import android.content.Context;

import com.flybits.commons.library.models.CtxData;
import com.flybits.commons.library.models.User;
import com.flybits.internal.db.models.CachingEntry;
import com.flybits.internal.db.models.Preference;

@Database(entities = {User.class, CachingEntry.class, Preference.class, CtxData.class}, version = 5)
public abstract class CommonsDatabase extends RoomDatabase {

    private final static String CREATE_TABLE_PREFERENCES = "CREATE TABLE preferences (id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, prefKey TEXT, value TEXT)";
    private final static String CREATE_TABLE_CTX_DATA = "CREATE TABLE ctxData (id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, timestamp INTEGER NOT NULL,value TEXT NOT NULL)";
    private final static String CREATE_TABLE_CACHINGENTRY = "CREATE TABLE cachingentry (sequence INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, cachingkey TEXT NOT NULL, contentID TEXT NOT NULL)";
    private final static String DROP_TABLE_CACHINGENTRY = "DROP TABLE IF EXISTS cachingentry";
    private final static String CREATE_INDEX_CACHING_ENTRY = "CREATE UNIQUE INDEX index_cachingentry_cachingkey_contentID on cachingentry (cachingkey, contentID)";
    private final static String ALTER_TABLE_USER_IS_VERIFIED = "ALTER TABLE user ADD isVerified INTEGER NOT NULL DEFAULT 0";



    private static CommonsDatabase INSTANCE;

    public abstract UserDAO userDao();
    public abstract CachingEntryDAO cachingEntryDAO();
    public abstract PreferenceDAO preferenceDAO();
    public abstract CtxDataDAO ctxDataDAO();

    public static CommonsDatabase getDatabase(Context context) {
        if (INSTANCE == null) {
            INSTANCE =
                    Room.databaseBuilder(context, CommonsDatabase.class, "commons-flybits-db")
                            .addMigrations(MIGRATION_1_4)
                            .addMigrations(MIGRATION_2_4)
                            .addMigrations(MIGRATION_3_4)
                            .addMigrations(MIGRATION_4_5)
                            .fallbackToDestructiveMigration()
                            .build();
                   /*
                    Room.inMemoryDatabaseBuilder(context.getApplicationContext(), ContextDatabase.class)
                            // To simplify the codelab, allow queries on the main thread.
                            // Don't do this on a real app! See PersistenceBasicSample for an example.
                            .allowMainThreadQueries()
                            .build();
                    */
        }
        return INSTANCE;
    }

    public static final Migration MIGRATION_1_4 = new Migration(1, 4) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL(ALTER_TABLE_USER_IS_VERIFIED);
            database.execSQL(DROP_TABLE_CACHINGENTRY);
            database.execSQL(CREATE_TABLE_CACHINGENTRY);
            database.execSQL(CREATE_INDEX_CACHING_ENTRY);
            database.execSQL(CREATE_TABLE_PREFERENCES);
        }
    };

    static final Migration MIGRATION_2_4 = new Migration(2, 4) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL(DROP_TABLE_CACHINGENTRY);
            database.execSQL(CREATE_TABLE_CACHINGENTRY);
            database.execSQL(CREATE_INDEX_CACHING_ENTRY);
            database.execSQL(CREATE_TABLE_PREFERENCES);
        }
    };

    static final Migration MIGRATION_3_4 = new Migration(3, 4) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL(CREATE_TABLE_PREFERENCES);
        }
    };

    static final Migration MIGRATION_4_5 = new Migration(4, 5) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL(CREATE_TABLE_CTX_DATA);
        }
    };

    public static void destroyInstance() {
        INSTANCE = null;
    }
}

==> commons-1.9.0-alpha2-sources.jar: com/flybits/internal/db/CommonsDatabase.java <==
package com.flybits.internal.db;

import android.arch.persistence.db.SupportSQLiteDatabase;
import android.arch.persistence.room.Database;
import android.arch.persistence.room.Room;
import android.arch.persistence.room.RoomDatabase;
import android.arch.persistence.room.migration.Migration;
import android.content.Context;

import com.flybits.commons.library.models.CtxData;
import com.flybits.commons.library.models.User;
import com.flybits.internal.db.models.CachingEntry;
import com.flybits.internal.db.models.Preference;

@Database(entities = {User.class, CachingEntry.class, Preference.class, CtxData.class}, version = 6)
public abstract class CommonsDatabase extends RoomDatabase {

    private final static String CREATE_TABLE_PREFERENCES = "CREATE TABLE preferences (id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, prefKey TEXT, value TEXT)";
    private final static String CREATE_TABLE_CTX_DATA = "CREATE TABLE ctxData (id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, timestamp INTEGER NOT NULL,value TEXT NOT NULL)";
    private final static String CREATE_TABLE_CACHINGENTRY = "CREATE TABLE cachingentry (sequence INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, cachingkey TEXT NOT NULL, contentID TEXT NOT NULL)";
    private final static String DROP_TABLE_CACHINGENTRY = "DROP TABLE IF EXISTS cachingentry";
    private final static String CREATE_INDEX_CACHING_ENTRY = "CREATE UNIQUE INDEX index_cachingentry_cachingkey_contentID on cachingentry (cachingkey, contentID)";
    private final static String ALTER_TABLE_USER_IS_VERIFIED = "ALTER TABLE user ADD isVerified INTEGER NOT NULL DEFAULT 0";
    private final static String ALTER_TABLE_USER_IS_OPTED_IN = "ALTER TABLE user ADD "+User.FIELD_IS_OPTED_IN+" INTEGER NOT NULL DEFAULT 1";



    private static CommonsDatabase INSTANCE;

    public abstract UserDAO userDao();
    public abstract CachingEntryDAO cachingEntryDAO();
    public abstract PreferenceDAO preferenceDAO();
    public abstract CtxDataDAO ctxDataDAO();

    public static CommonsDatabase getDatabase(Context context) {
        if (INSTANCE == null) {
            INSTANCE =
                    Room.databaseBuilder(context, CommonsDatabase.class, "commons-flybits-db")
                            .addMigrations(MIGRATION_1_4)
                            .addMigrations(MIGRATION_2_4)
                            .addMigrations(MIGRATION_3_4)
                            .addMigrations(MIGRATION_4_5)
                            .fallbackToDestructiveMigration()
                            .build();
                   /*
                    Room.inMemoryDatabaseBuilder(context.getApplicationContext(), ContextDatabase.class)
                            // To simplify the codelab, allow queries on the main thread.
                            // Don't do this on a real app! See PersistenceBasicSample for an example.
                            .allowMainThreadQueries()
                            .build();
                    */
        }
        return INSTANCE;
    }

    public static final Migration MIGRATION_1_4 = new Migration(1, 4) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL(ALTER_TABLE_USER_IS_VERIFIED);
            database.execSQL(DROP_TABLE_CACHINGENTRY);
            database.execSQL(CREATE_TABLE_CACHINGENTRY);
            database.execSQL(CREATE_INDEX_CACHING_ENTRY);
            database.execSQL(CREATE_TABLE_PREFERENCES);
        }
    };

    static final Migration MIGRATION_2_4 = new Migration(2, 4) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL(DROP_TABLE_CACHINGENTRY);
            database.execSQL(CREATE_TABLE_CACHINGENTRY);
            database.execSQL(CREATE_INDEX_CACHING_ENTRY);
            database.execSQL(CREATE_TABLE_PREFERENCES);
        }
    };

    static final Migration MIGRATION_3_4 = new Migration(3, 4) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL(CREATE_TABLE_PREFERENCES);
        }
    };

    static final Migration MIGRATION_4_5 = new Migration(4, 5) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL(CREATE_TABLE_CTX_DATA);
        }
    };

    static final Migration MIGRATION_5_6 = new Migration(5, 6) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL(ALTER_TABLE_USER_IS_OPTED_IN);
        }
    };

    public static void destroyInstance() {
        INSTANCE = null;
    }
}
